@@ -1,5 +1,18 @@
 var NAVTREEINDEX8 =
 {
+"structpw__protocol__client.html#a020b1da93f4f58c485ff64da4a5ac655":[10,0,88,0],
+"structpw__protocol__client.html#a03ad2913f7876e0db722b6d1e318e35f":[10,0,88,2],
+"structpw__protocol__client.html#a0f94b0fb5b1f83cbb56529b5c43c4a8f":[10,0,88,1],
+"structpw__protocol__client.html#a2f6233dcd7a026275a93680ae68ee263":[10,0,88,6],
+"structpw__protocol__client.html#a4b60903a56e79e980b11ea2d14fac80c":[10,0,88,4],
+"structpw__protocol__client.html#a4f79f140a57922a8c4b7d52f9f433918":[10,0,88,7],
+"structpw__protocol__client.html#a9ce571a5bc950b3309d0dbd2a55e501f":[10,0,88,3],
+"structpw__protocol__client.html#addd42578b59ddffc32a42a52754654be":[10,0,88,5],
+"structpw__protocol__client.html#ae94059a4fa05da14961edb56be183f2a":[10,0,88,8],
+"structpw__protocol__events.html":[10,0,89],
+"structpw__protocol__events.html#ab341415c5d72294c801c580ac9653426":[10,0,89,0],
+"structpw__protocol__events.html#af7bb9abb40f974acecda6bb2c6ad5cad":[10,0,89,1],
+"structpw__protocol__implementaton.html":[10,0,90],
 "structpw__protocol__implementaton.html#a5dbc29661309ba54e93539eae72ba595":[10,0,90,0],
 "structpw__protocol__implementaton.html#aa8898b554d834734e02a66de773449ad":[10,0,90,2],
 "structpw__protocol__implementaton.html#ae2b02b226f7b843e488fba013635c990":[10,0,90,1],
@@ -77,16 +90,17 @@ var NAVTREEINDEX8 =
 "structregistry.html":[10,0,108],
 "structregistry.html#a395958760b70738836a0aaad7d641fbf":[10,0,108,0],
 "structresource__data.html":[10,0,109],
-"structresource__data.html#a10818e72fb4b7e69e713b6e4f1cfe4b5":[10,0,109,7],
+"structresource__data.html#a10818e72fb4b7e69e713b6e4f1cfe4b5":[10,0,109,8],
 "structresource__data.html#a17b2ae2575ff92e24e1295b5cf8dd040":[10,0,109,0],
 "structresource__data.html#a1ba0b9c4f96dec005b0579a9fe4097ed":[10,0,109,1],
 "structresource__data.html#a2c356777100b44207f8b9c2bfa0dc7ef":[10,0,109,2],
-"structresource__data.html#a50161316a8dbc6f017625d7ae7cc1830":[10,0,109,9],
+"structresource__data.html#a4359b8e5ca98a4da69d920c155f759f5":[10,0,109,6],
+"structresource__data.html#a50161316a8dbc6f017625d7ae7cc1830":[10,0,109,10],
 "structresource__data.html#a53c387cc88d8b3aabdeb5f21a7524df0":[10,0,109,4],
-"structresource__data.html#a6cc97539aba095db1fa33569183e4e04":[10,0,109,6],
+"structresource__data.html#a6cc97539aba095db1fa33569183e4e04":[10,0,109,7],
 "structresource__data.html#a70a2dfa3889e379272d25fece3591f6f":[10,0,109,5],
 "structresource__data.html#a7bdfe353b29ac14ebe5b645618c18d2a":[10,0,109,3],
-"structresource__data.html#ac695a0f85d24f0a28cb971cc4a7ca191":[10,0,109,8],
+"structresource__data.html#ac695a0f85d24f0a28cb971cc4a7ca191":[10,0,109,9],
 "structresult__device__params__data.html":[10,0,110],
 "structresult__device__params__data.html#a485ab9bc6d5dbaf4285876053b8f1902":[10,0,110,0],
 "structresult__device__params__data.html#af601dbb7d11417aae89f45c1749ced54":[10,0,110,1],
