@@ -5,10 +5,10 @@ var structfilter =
     [ "change_mask_all", "structfilter.html#a373d3bc6daf14edc724048bd412caa8e", null ],
     [ "context", "structfilter.html#a576795bfa992c35fddb427543ad5bd59", null ],
     [ "data", "structfilter.html#a411f8b027a2391acb338416baee33d71", null ],
+    [ "disconnect_core", "structfilter.html#a0f722c6917d852102b79e08b806d487d", null ],
     [ "disconnecting", "structfilter.html#a0e58480b42495dee8001219fb2b57968", null ],
     [ "draining", "structfilter.html#aea66d542b1b385ea8bccd0c2e54d5a68", null ],
     [ "flags", "structfilter.html#a42bfb93f6d5383083c0f5288a43836a4", null ],
-    [ "free_proxy", "structfilter.html#a439cf5f985754c946aaa49ab0232845e", null ],
     [ "hooks", "structfilter.html#a25920211071120caccb1773f36a5048f", null ],
     [ "impl_node", "structfilter.html#a3d3bbf50569618ec2aaaf732be2b939a", null ],
     [ "info", "structfilter.html#a78a505bffa0426e75fd31047717d1352", null ],
@@ -18,6 +18,7 @@ var structfilter =
     [ "port_list", "structfilter.html#ab8c65999c3601116155e31cd7d47e232", null ],
     [ "ports", "structfilter.html#affe704740ff57363fdb29fb7ef558666", null ],
     [ "position", "structfilter.html#a00baa7796ebf97e59863106d73640a19", null ],
+    [ "rt", "structfilter.html#ac2f65174639e5113b0a4a597c1d67bb4", null ],
     [ "seq", "structfilter.html#a033a9d50fe013ff96d02fb23d767521d", null ],
     [ "subscribe", "structfilter.html#ac387f99d6533daf6511189240eb0846c", null ],
     [ "this", "structfilter.html#af6ec9143b41642c1b07e90eba876ad92", null ],
